@@ -9,7 +9,7 @@ use yozuk_helper_english::normalized_eq;
 use yozuk_sdk::prelude::*;
 
 pub const ENTRY: SkillEntry = SkillEntry {
-    model_id: b"poiiZamzXE0JVgxUfo6Pr",
+    model_id: b"s58l68IJz5WVuF9yYJj2o",
     config_schema: None,
     init: |_, _| {
         Skill::builder()
@@ -39,8 +39,7 @@ impl Corpus for BitcoinCorpus {
                     ]),
                 ]
             })
-            .chain(vec![tk!(["bitcoin"; "command:bitcoin"]); 10])
-            .chain(vec![tk!(["btc"; "command:bitcoin"]); 10])
+            .chain(Some(tk!(["bitcoin"; "command:bitcoin"])))
             .collect()
     }
 }
@@ -74,14 +73,11 @@ impl Command for BitcoinCommand {
         let private_key = PrivateKey::new(privkey, Network::Bitcoin);
         let public_key = PublicKey::new(pubkey);
         let address = Address::p2pkh(&public_key, Network::Bitcoin);
-        Ok(Output {
-            title: "Bitcoin".into(),
-            blocks: vec![
-                Block::Comment(block::Comment::new().set_text("Generating a new address")),
-                Block::Data(block::Data::new().set_text_data(address.to_string())),
-                Block::Spoiler(block::Spoiler::new("Private Key", private_key.to_wif())),
-            ],
-            ..Default::default()
-        })
+
+        Ok(Output::new().set_title("Bitcoin").add_blocks(vec![
+            Block::Comment(block::Comment::new().set_text("Generating a new address")),
+            Block::Data(block::Data::new().set_text_data(address.to_string())),
+            Block::Spoiler(block::Spoiler::new("Private Key", private_key.to_wif())),
+        ]))
     }
 }
